**EN 1993-1-9 - May 2005
Eurocode 3: Design of steel structures
Part 1-9: Fatigue**

The table presents a list of formulas from the Eurocode 3 standards for steel structures, tracking their implementation status (:x: or :heavy_check_mark:)
and any pertinent remarks. The 'Object Name' column references the corresponding Python entities inside of Blueprints.

Total of 11 formulas present.

| Formula number | Done | Remarks | Object name |
|:---------------|:----:|:--------|:------------|
| 6.1            | :x:  |         |             |
| 6.2            | :x:  |         |             |
| 6.3            | :x:  |         |             |
| 6.4            | :x:  |         |             |
| 7.1            | :x:  |         |             |
| 8.1            | :x:  |         |             |
| 8.2            | :x:  |         |             |
| 8.3            | :x:  |         |             |
| A.1            | :heavy_check_mark: |         | FormADot1DamageDuringDesignLife |
| A.2            | :heavy_check_mark: |         | FormADot2CriteriaBasedOnDamageAccumulation |
| A.3            | :x:  |         |             |
